"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateBundleIdentifier = exports.validateProjectName = void 0;
var pretty_1 = require("./pretty");
var isIgnite = [
    function (str) { return str.toLowerCase() === "ignite"; },
    function (str) { return "Hey...that's my name! Please name your project something other than '".concat(str, "'."); },
];
var isOnlyNumbers = [
    function (str) { return /^\d+$/.test(str); },
    function () { return "Please use at least one non-numeric character for your project name"; },
];
var isNotAlphaNumeric = [
    function (str) { return !/^[a-z_][a-z0-9_-]+$/i.test(str); },
    function () {
        return "The project name can only contain alphanumeric characters and underscore, but must not begin with a number.";
    },
];
var guards = [isIgnite, isOnlyNumbers, isNotAlphaNumeric];
/**
 * check if the value matches any of the error guards
 * @returns error message from the first guard that matches, or `true` if no guards match
 */
var validate = function (value) {
    for (var _i = 0, guards_1 = guards; _i < guards_1.length; _i++) {
        var _a = guards_1[_i], isError = _a[0], errorMessage = _a[1];
        if (isError(value)) {
            return errorMessage(value);
        }
    }
    return true;
};
// #endregion
function validateProjectName(toolbox) {
    return __awaiter(this, void 0, void 0, function () {
        var parameters, strings, print, isBlank, projectName, projectNameResponse, error;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    parameters = toolbox.parameters, strings = toolbox.strings, print = toolbox.print;
                    isBlank = strings.isBlank;
                    projectName = (parameters.first || "").toString();
                    if (!isBlank(projectName)) return [3 /*break*/, 2];
                    return [4 /*yield*/, toolbox.prompt.ask(function () { return ({
                            name: "projectName",
                            type: "input",
                            message: "What do you want to call it?",
                            prefix: pretty_1.prefix,
                            validate: validate,
                        }); })];
                case 1:
                    projectNameResponse = _a.sent();
                    projectName = projectNameResponse.projectName;
                    _a.label = 2;
                case 2:
                    // warn if more than one argument is provided for <projectName>
                    if (parameters.second) {
                        print.info("Info: You provided more than one argument for <projectName>. The first one (".concat(projectName, ") will be used and the rest are ignored.")); // prettier-ignore
                    }
                    error = validate(projectName);
                    if (typeof error === "string") {
                        print.error(error);
                        process.exit(1);
                    }
                    return [2 /*return*/, projectName];
            }
        });
    });
}
exports.validateProjectName = validateProjectName;
function validateBundleIdentifier(toolbox, bundleID) {
    var print = toolbox.print;
    // no bundle ID provided
    if (bundleID === undefined)
        return undefined;
    var id = bundleID.split(".");
    var validBundleID = /^([a-zA-Z]([a-zA-Z0-9_])*\.)+[a-zA-Z]([a-zA-Z0-9_])*$/u;
    if (id.length < 2) {
        print.error('Invalid Bundle Identifier. Add something like "com.travelapp" or "com.junedomingo.travelapp"');
        process.exit(1);
    }
    if (!validBundleID.test(bundleID)) {
        print.error("Invalid Bundle Identifier. It must have at least two segments (one or more dots). Each segment must start with a letter. All characters must be alphanumeric or an underscore [a-zA-Z0-9_]");
        process.exit(1);
    }
    return bundleID;
}
exports.validateBundleIdentifier = validateBundleIdentifier;
//# sourceMappingURL=validations.js.map